;; HYPRVAR.LSP Copyright 1998-2005 HyperPics all rights reserved
;;
;;HyperPics can be contacted at:
;;  http://www.hyperpics.com
;;      lee_ambrosius@hyperpics.com
;;
;;  Author: Lee Ambrosius,
;;             HyperPics

;;HyperPics Variables to Script
;; Used in conjunction with Vars15.txt file.  The Variables 
;; text file contains the names of the variables for the LISP 
;; program to extract and write to the script file.  The program 
;; will grab the current variable settings from AutoCAD and create
;; a script file from it.
;; The routine will work with R12, R13, R14, R2000, R2000i, R2002,
;; R2004, R2005 and R2006.

;; AutoCAD Releases:
;; Release 12 - Vars12.txt      (Created 1998)
;; Release 13 - Vars13.txt      (Created 1998)
;; Release 14 - Vars14.txt      (Created 1998)
;; Release 2000 - Vars15.txt    (Created 2000)
;; Release 2000i - Vars15_5.txt (Created 2003)
;; Release 20002 - Vars15_6.txt (Created 2003)
;; Release 2004 - Vars16.txt    (Created 2003)
;; Release 2005 - Vars16_1.txt  (Created 2004)
;; Release 2006 - Vars16_2.txt  (Created 2005)

;; Once it is done running, you will notice that in the same location
;; as the vars1X.txt file.  A file called vars.scr was created.  This
;; is now your new script file to recover your variables if they get
;; all messed up or it is a great way to make sure that all your variables
;; are correct after opening up a client or customers drawing.  When needed
;; load the script file and your backup and running.

;; Revision on 4/24/03
;; Added support for 2000i, 2002 and 2004 specific variables

;; Revision on 7/01/04
;; Added support for 2005 specific variables and changed the output to help with data
;; by going to a LISP based

;; Revision on 9/12/05
;; Added support for 2006 specific variables 

(prompt "\nHyperPics Variable to Script generator V1.31 is loaded.")
(prompt "\nType HYPRVAR to run.")(princ)


(defun c:HYPRVAR ()
  ;; Get text file that is related to AutoCAD Version
  (cond
    ((= (getvar "acadver") "12.0")(c:HYPRVAR-LEGACY))
    ((= (getvar "acadver") "13.0")(c:HYPRVAR-LEGACY))
    ((or (= (getvar "acadver") "14.0")(= (getvar "acadver") "14.01"))(c:HYPRVAR-LEGACY))
    ((= (getvar "acadver") "15.0")(c:HYPRVAR-NEW))
    ((= (getvar "acadver") "15.05")(c:HYPRVAR-NEW))
    ((= (getvar "acadver") "15.06")(c:HYPRVAR-NEW))
    ((= (substr (getvar "acadver") 1 4) "16.0")(c:HYPRVAR-NEW))
    ((= (substr (getvar "acadver") 1 4) "16.1")(c:HYPRVAR-NEW))
    ((= (substr (getvar "acadver") 1 4) "16.2")(c:HYPRVAR-NEW))
  )
)

(defun c:HYPRVAR-NEW (/ FILE VAR-FP WVAR-FP bWriteOutValue)
  (vl-load-com)

  ;; Convert Radians to Degrees
  (defun RTD (rad)
    (* (/ rad PI) 180)
  )

  ;; Convert Degrees to Radians
  (defun DTR (deg)
    (* deg (/ PI 180))
  )

  ;; Get text file that is related to AutoCAD Version
  (cond
    ((= (getvar "acadver") "15.0")(setq VFILE "vars15.txt"))
    ((= (getvar "acadver") "15.05")(setq VFILE "vars15_5.txt"))
    ((= (getvar "acadver") "15.06")(setq VFILE "vars15_6.txt"))
    ((= (substr (getvar "acadver") 1 4) "16.0")(setq VFILE "vars16.txt"))
    ((= (substr (getvar "acadver") 1 4) "16.1")(setq VFILE "vars16_1.txt"))
    ((= (substr (getvar "acadver") 1 4) "16.2")(setq VFILE "vars16_2.txt"))
  )

  (setq FILE (findfile VFILE))
  (if (/= FILE nil)
    (progn
      (setq VAR-FP (open FILE "r"))

      (setq WFILE (strcat (substr FILE 1 (- (strlen FILE) 10)) (strcat (substr VFILE 1 (- (strlen VFILE) 4)) ".scr")))
      (setq WVAR-FP (open WFILE "w"))
      
      (setq VAR (read-line VAR-FP))	 
      (while (/= VAR nil)

        (setq bWriteOutValue T)
        (setq GVAR (getvar VAR))

        ;; Conditional to handle Color Plot Styles
        (if (= (type GVAR) 'STR)
          (progn
            (if (and (= (strcase GVAR) "BYCOLOR")(or
                                                    (= (strcase VAR) "CPLOTSTYLE")
                                                    (= (strcase VAR) "DEFLPLSTYLE")
                                                    (= (strcase VAR) "DEFPLSTYLE")
                                                 )
                )
              (setq bWriteOutValue nil)
              (setq bWriteOutValue T)
            )
            ;; PlotID can't be set to a dot
            (if (and (= GVAR "")(= (strcase VAR) "PLOTID")) (setq bWriteOutValue nil))
            (if (and (= GVAR "")(/= (strcase VAR) "PLOTID"))(setq GVAR "."))

            (setq GVAR (strcat "\"" GVAR "\""))

            ;; Change back slashes to forward slashes for pathing
            (while (vl-string-position (ascii "\\") GVAR)
              (setq GVAR (vl-string-subst "/" "\\" GVAR))
            )
          )
        )

        (if (= (type GVAR) 'INT)(setq GVAR (itoa GVAR)))
        (if (= (type GVAR) 'REAL)(setq GVAR (rtos GVAR 2 4)))
        (if (= (type GVAR) 'LIST)
          (progn
            (setq GPT1 nil GPT2 nil GPT3 nil)
            (setq GPT1 (rtos (car GVAR) 2 6))
	      (setq GVAR (cdr GVAR))
	      (setq GPT2 (rtos (car GVAR) 2 6))
	      (setq GVAR (cdr GVAR))
	      (if (/= GVAR nil)
	        (setq GPT3 (rtos (car GVAR) 2 6))
            )
	      (if (/= GPT3 nil)
	        (setq GVAR (strcat "'(" GPT1 " " GPT2 " " GPT3 ")"))
	        (setq GVAR (strcat "'(" GPT1 " " GPT2 ")"))
	      )
          )
        )

        (if (and (or 
                   (= (substr (getvar "acadver") 1 2) "15")
                   (= (substr (getvar "acadver") 1 2) "16")
                 )(= VAR "UCSAXISANG")
            )
            (setq GVAR (rtos (rtd (atof GVAR)) 2 0))
        )

        (if (= bWriteOutValue T)
          (progn
            (princ VAR)(terpri)
            (if (= (strcase VAR) "UCSAXISANG")
              (write-line (strcat "(COMMAND \"" VAR "\" " GVAR ")")  WVAR-FP)
              (write-line (strcat "(SETVAR \"" VAR "\" " GVAR ")")  WVAR-FP)
            )
          )
        )

        (setq VAR (read-line VAR-FP))
      )
      (close VAR-FP)
      (close WVAR-FP)
      (setq MSG (strcat "\n" WFILE " has been created."))
    )
    (setq MSG (strcat "\n" (strcase VFILE) " was not found in the AutoCAD support paths.\nPlease verify that it is still there."))
  )
  (prompt MSG)
 (princ)
)

(defun c:HYPRVAR-LEGACY (/ FILE VAR-FP WVAR-FP)

  ;; Convert Radians to Degrees
  (defun RTD (rad)
    (* (/ rad PI) 180)
  )

  ;; Convert Degrees to Radians
  (defun DTR (deg)
    (* deg (/ PI 180))
  )

  ;; Get text file that is related to AutoCAD Version
  (cond
    ((= (getvar "acadver") "12.0")(setq VFILE "vars12.txt"))
    ((= (getvar "acadver") "13.0")(setq VFILE "vars13.txt"))
    ((or (= (getvar "acadver") "14.0")(= (getvar "acadver") "14.01"))(setq VFILE "vars14.txt"))
  )

  (setq FILE (findfile VFILE))
  (if (/= FILE nil)
    (progn
      (setq VAR-FP (open FILE "r"))

      (setq WFILE (strcat (substr FILE 1 (- (strlen FILE) 10)) (strcat (substr VFILE 1 (- (strlen VFILE) 4)) ".scr")))
      (setq WVAR-FP (open WFILE "w"))
      
      (setq VAR (read-line VAR-FP))	 
      (while (/= VAR nil)
        (setq GVAR (getvar VAR))
        (if (= (type GVAR) 'INT)(setq GVAR (itoa GVAR)))
        (if (= (type GVAR) 'REAL)(setq GVAR (rtos GVAR 2 4)))
        (if (= (type GVAR) 'LIST)
          (progn
            (setq GPT1 nil GPT2 nil GPT3 nil)
            (setq GPT1 (rtos (car GVAR) 2 6))
	      (setq GVAR (cdr GVAR))
	      (setq GPT2 (rtos (car GVAR) 2 6))
	      (setq GVAR (cdr GVAR))
	      (if (/= GVAR nil)
	        (setq GPT3 (rtos (car GVAR) 2 6))
            )
	      (if (/= GPT3 nil)
	        (setq GVAR (strcat GPT1 "," GPT2 "," GPT3))
	        (setq GVAR (strcat GPT1 "," GPT2))
	      )
          )
        )
        (if (= GVAR "")(setq GVAR "."))

        (princ VAR)(terpri)
        (write-line "SETVAR" WVAR-FP)
        (write-line VAR WVAR-FP)
        (write-Line GVAR WVAR-FP)

        (setq VAR (read-line VAR-FP))
      )
      (close VAR-FP)
      (close WVAR-FP)
      (setq MSG (strcat "\n" WFILE " has been created."))
    )
    (setq MSG (strcat "\n" (strcase VFILE) " was not found in the AutoCAD support paths.\nPlease verify that it is still there."))
  )
  (prompt MSG)
 (princ)
)

(princ)